package com.gic.enterprise.service;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.enterprise.dto.union.*;
import com.gic.enterprise.qo.union.UnionEnterpriseAuthResLogQO;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import java.util.List;

/**
 * 联合商户
 * @ClassName:
 * @Description:  
 * @author guojuxing 
 * @date 2021/2/3 1:47 PM 
 */
public interface UnionEnterpriseAuthApiService {

    /**
     * 创建联合商户
     * @param ownEnterpriseId
     * @param unionEnterpriseId
     * @return
     */
    ServiceResponse<Void> saveUnionEnterprise(@NotNull Integer ownEnterpriseId, @NotNull Integer unionEnterpriseId);

    /**
     * 授权资源
     * @param dto
     * @return
     */
    ServiceResponse<Void> authResource(@Valid UnionEnterpriseAuthResDTO dto);

    /**
     * 查询联合商户记录
     * @param ownEnterpriseId
     * @param unionEnterpriseId
     * @return
     */
    ServiceResponse<UnionEnterpriseAuthDTO> getUnionEnterpriseAuth(@NotNull Integer ownEnterpriseId, @NotNull Integer unionEnterpriseId);

    /**
     * 资源重新授权
     * @param ownEnterpriseId
     * @param unionEnterpriseId
     * @param resourceType UnionEnterpriseAuthResTypeEnum
     * @return
     */
    ServiceResponse<Void> resetAuthResource(@NotNull Integer ownEnterpriseId, @NotNull Integer unionEnterpriseId, @NotNull Integer resourceType);

    /**
     * 解除联合
     * @param ownEnterpriseId
     * @param unionEnterpriseId
     * @param relieveReason 解除理由
     * @return
     */
    ServiceResponse<Void> relieveUnion(Integer ownEnterpriseId, Integer unionEnterpriseId, String relieveReason);

    /**
     * 联合商户列表
     * @param ownEnterpriseId 自有商户ID
     * @param enterpriseName 联合商户名称
     * @param authStatus UnionEnterpriseAuthDetailStatusEnum
     * @return
     */
    ServiceResponse<List<UnionEnterpriseAuthListDTO>> listUnionEnterpriseAuth(@NotNull Integer ownEnterpriseId, String enterpriseName, Integer authStatus);

    /**
     * 查询联合商户数据
     * @param ownEnterpriseId
     * @return
     */
    ServiceResponse<List<UnionEnterpriseAuthDTO>> listUnionEnterpriseAuth(@NotNull Integer ownEnterpriseId);


    /**************应用策略************************/

    /**
     * 新增/更新策略
     * @param dto
     * @return
     */
    ServiceResponse<Void> saveOrUpdateUnionEnterpriseAuthApp(@Valid UnionEnterpriseAuthAppDTO dto);

    /**
     * 策略详情
     * @param unionEnterpriseAuthAppId
     * @return
     */
    ServiceResponse<UnionEnterpriseAuthAppDTO> getUnionEnterpriseAuthApp(@NotNull Integer unionEnterpriseAuthAppId);

    /**
     * 策略列表
     * @param ownEnterpriseId
     * @param unionEnterpriseId
     * @return
     */
    ServiceResponse<List<UnionEnterpriseAuthAppDTO>> listUnionEnterpriseAuthApp(@NotNull Integer ownEnterpriseId, @NotNull Integer unionEnterpriseId);

    /**
     * 删除应用策略
     * @param unionEnterpriseAuthAppId
     * @return
     */
    ServiceResponse<String> deleteUnionEnterpriseAuthApp(@NotNull Integer unionEnterpriseAuthAppId);

    /**
     * 批量删除接口
     * @param unionEnterpriseAuthId
     * @return
     */
    ServiceResponse<String> deleteUnionEnterpriseAuthAppByUnionEnterpriseAuthId(@NotNull Integer unionEnterpriseAuthId);

    /**
     * 到期发送解除联合通知
     * @param param
     * @return
     */
    ServiceResponse<Void> relieveTask(String param);
    /********联合商户视角接口***********/

    /**
     * 自有商户列表
     * @param unionEnterpriseId
     * @param startTime
     * @param endTime
     * @return
     */
    ServiceResponse<List<OwnEnterpriseAuthListDTO>> listOwnEnterpriseAuth(@NotNull Integer unionEnterpriseId, String startTime, String endTime);

    /**
     * 操作日志
     * @param param
     * @return
     */
    ServiceResponse<Page<UnionEnterpriseAuthResLogDTO>> listUnionEnterpriseAuthResLog(UnionEnterpriseAuthResLogQO param);
}
